package com.bonus.material.lease.service;

import java.util.List;
import com.bonus.material.lease.domain.LeaseSceneRegist;

/**
 * 项目部出入记录Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface ILeaseSceneRegistService {
    /**
     * 查询项目部出入记录
     * 
     * @param id 项目部出入记录主键
     * @return 项目部出入记录
     */
    public LeaseSceneRegist selectLeaseSceneRegistById(Long id);

    /**
     * 查询项目部出入记录列表
     * 
     * @param leaseSceneRegist 项目部出入记录
     * @return 项目部出入记录集合
     */
    public List<LeaseSceneRegist> selectLeaseSceneRegistList(LeaseSceneRegist leaseSceneRegist);

    /**
     * 新增项目部出入记录
     * 
     * @param leaseSceneRegist 项目部出入记录
     * @return 结果
     */
    public int insertLeaseSceneRegist(LeaseSceneRegist leaseSceneRegist);

    /**
     * 修改项目部出入记录
     * 
     * @param leaseSceneRegist 项目部出入记录
     * @return 结果
     */
    public int updateLeaseSceneRegist(LeaseSceneRegist leaseSceneRegist);

    /**
     * 批量删除项目部出入记录
     * 
     * @param ids 需要删除的项目部出入记录主键集合
     * @return 结果
     */
    public int deleteLeaseSceneRegistByIds(Long[] ids);

    /**
     * 删除项目部出入记录信息
     * 
     * @param id 项目部出入记录主键
     * @return 结果
     */
    public int deleteLeaseSceneRegistById(Long id);
}
