package com.bonus.material.lease.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.lease.domain.LeaseSceneRegist;
import com.bonus.material.lease.service.ILeaseSceneRegistService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 项目部出入记录Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "项目部出入记录接口")
@RestController
@RequestMapping("/lease_scene_regist")
public class LeaseSceneRegistController extends BaseController {
    @Autowired
    private ILeaseSceneRegistService leaseSceneRegistService;

    /**
     * 查询项目部出入记录列表
     */
    @ApiOperation(value = "查询项目部出入记录列表")
    @RequiresPermissions("lease:regist:list")
    @GetMapping("/list")
    public TableDataInfo list(LeaseSceneRegist leaseSceneRegist) {
        startPage();
        List<LeaseSceneRegist> list = leaseSceneRegistService.selectLeaseSceneRegistList(leaseSceneRegist);
        return getDataTable(list);
    }

    /**
     * 导出项目部出入记录列表
     */
    @ApiOperation(value = "导出项目部出入记录列表")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:regist:export")
    @SysLog(title = "项目部出入记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出项目部出入记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, LeaseSceneRegist leaseSceneRegist) {
        List<LeaseSceneRegist> list = leaseSceneRegistService.selectLeaseSceneRegistList(leaseSceneRegist);
        ExcelUtil<LeaseSceneRegist> util = new ExcelUtil<LeaseSceneRegist>(LeaseSceneRegist.class);
        util.exportExcel(response, list, "项目部出入记录数据");
    }

    /**
     * 获取项目部出入记录详细信息
     */
    @ApiOperation(value = "获取项目部出入记录详细信息")
    @RequiresPermissions("lease:regist:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(leaseSceneRegistService.selectLeaseSceneRegistById(id));
    }

    /**
     * 新增项目部出入记录
     */
    @ApiOperation(value = "新增项目部出入记录")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:regist:add")
    @SysLog(title = "项目部出入记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增项目部出入记录")
    @PostMapping
    public AjaxResult add(@RequestBody LeaseSceneRegist leaseSceneRegist) {
        try {
            return toAjax(leaseSceneRegistService.insertLeaseSceneRegist(leaseSceneRegist));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改项目部出入记录
     */
    @ApiOperation(value = "修改项目部出入记录")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:regist:edit")
    @SysLog(title = "项目部出入记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改项目部出入记录")
    @PutMapping
    public AjaxResult edit(@RequestBody LeaseSceneRegist leaseSceneRegist) {
        try {
            return toAjax(leaseSceneRegistService.updateLeaseSceneRegist(leaseSceneRegist));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除项目部出入记录
     */
    @ApiOperation(value = "删除项目部出入记录")
    @PreventRepeatSubmit
    @RequiresPermissions("lease:regist:remove")
    @SysLog(title = "项目部出入记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除项目部出入记录")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(leaseSceneRegistService.deleteLeaseSceneRegistByIds(ids));
    }
}
